<?php

/**
 * The categories-specific functionality of the plugin.
 *
 * @link       https://www.sortd.mobi
 * @since      2.0.0
 *
 * @package    Sortd
 * @subpackage Sortd/admin
 */

/**
 * The categories-specific functionality of the plugin.
 *
 * @package    Sortd
 * @subpackage Sortd/admin
 * @author     Your Name <email@example.com>
 */
class Sortd_Categories {
        
        /**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Sortd_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $sortd    The ID of this plugin.
	 */
	private $sortd;

    private $html;

    private $all_categories;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $sortd       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $sortd, $version, $loader ) {

		$this->sortd    = $sortd;
		$this->version  = $version;
        $this->loader   = $loader;

	}
        
        /**
	 * function to define module specific hooks
	 *
	 * @since    2.0.0
	 */
	public function define_hooks() {

        $this->loader->add_action( 'admin_enqueue_scripts', $this, 'enqueue_scripts' );
        $this->loader->add_action('wp_ajax_sortd_sync_unsync_category', $this, 'sync_category');
        $this->loader->add_action('wp_ajax_sortd_ajax_reorder_rename_category', $this, 'reorder_rename_category_ajax');
        $this->loader->add_action('wp_ajax_sortd_ajax_rename_category', $this, 'save_renamed_category');
        $this->loader->add_action('wp_ajax_sortd_ajax_save_reorder_category', $this, 'save_reordered_categories');
        $this->loader->add_action('wp_ajax_get_cat_children', $this, 'get_cat_children');
        $this->loader->add_action('wp_ajax_get_all_heirarchy_cat_children', $this, 'get_all_heirarchy_cat_children');
        $this->loader->add_action('wp_ajax_check_for_synced', $this, 'check_for_synced');
        $this->loader->add_action('wp_ajax_get_categories', $this, 'sortd_get_categories');
        $this->loader->add_action('wp_ajax_sortd_category_url_redirection', $this, 'update_category_url_redirection');
        $this->loader->add_action('wp_ajax_sortd_article_url_redirection', $this, 'update_article_url_redirection');
        
	}
        
        /**
	 * function for including scripts
	 *
	 * @since    2.0.0
	 */
        public function enqueue_scripts() {

            $current_page = get_current_screen()->base;

           // echo $current_page;die;

          if($current_page == 'edit_tags'){

            wp_enqueue_script('sortd-taxonomyjs', SORTD_JS_URL . '/sortd-taxonomy.js', array( 'jquery' ), $this->version, true );
            wp_localize_script(
                'sortd-taxonomyjs',
                'sortd_ajax_obj_category',
                array(
                    'ajax_url' => admin_url( 'admin-ajax.php' ),
                    'nonce'    => wp_create_nonce( 'sortd-ajax-nonce-category' ),
                )
            );

          } else if($current_page == 'sortd_page_sortd-manage-settings'){
            wp_enqueue_script('sortd-category', SORTD_JS_URL . '/sortd-category.js', array( 'jquery' ), $this->version, true );
            wp_localize_script(
                'sortd-category',
                'sortd_ajax_obj_category',
                array(
                    'ajax_url' => admin_url( 'admin-ajax.php' ),
                    'nonce'    => wp_create_nonce( 'sortd-ajax-nonce-category' ),
                )
            );

        }
        
         
            wp_enqueue_script( 'sweet-alert-message-js', SORTD_JS_URL . '/sweetalert.min.js', array( 'jquery' ), $this->version, true );
            wp_enqueue_script('jqueryuisort', SORTD_JS_URL . '/jqueryui-sort.min.js',array( ), $this->version, true);
            wp_enqueue_script( 'nestedSortable', SORTD_JS_URL . '/jquery.mjs.nestedSortable.min.js', array( 'jquery' ), $this->version, true );
          
            
            
                
        }

	

	/**
	 * function for manage categories screen
	 *
	 * @since    2.0.0
	 */
	public function manage_categories() {

            $category_order = $categories = array();
            $project_id          = Sortd_Helper::get_project_id();
            $categories_api_slug = 'contentsettings/listcategories';

            $response = Sortd_Helper::sortd_get_api_response($categories_api_slug,'v2');

            if($response){
                $response   = json_decode($response,TRUE);
                $categories = isset($response['data']) ? $response['data']:array();
            }
		
            if(!empty($categories)){
                foreach ($categories as $category) {
                   // if($category['cat_type']=='1') {
                        $category_order[]['id'] = $category;//$category['_id'];
                  //  }
                }
            }  
            
           
            $taxonomy     = 'category';
            $orderby      = 'name';  
            $show_count   = 0;      
            $pad_counts   = 0;      
            $hierarchical = 1;     
            $title        = '';  
            $empty        = 0;

            $args = array(
                   'taxonomy'     => $taxonomy,
                   'orderby'      => $orderby,
                   'show_count'   => $show_count,
                   'pad_counts'   => $pad_counts,
                   'hierarchical' => $hierarchical,
                   'title_li'     => $title,
                   'hide_empty'   => $empty
            );
            
            $this->all_categories = get_categories( $args );
            $flag =  $this->getHtml(0,0, $project_id);

            if($flag == true){
                $render_html =  $this->html;
            }
            
            
            $action = "sync";
            
            if(isset($_GET['action']) && $_GET['action'] == 'reorder'){
                $action = 'reorder';
            }
            
            $view_data = array();
            $view_data['category_order']    = wp_json_encode($category_order);
            $view_data['categories']        = $categories;
            $view_data['all_categories']    = $this->all_categories;
            $view_data['project_id']        = $project_id;
            $view_data['response']          = $response;
            $view_data['action']            = $action;
            $view_data['html_data']         = $render_html;

            Sortd_Helper::render_partials(array('sortd-categories-manage', 'sortd-categories-sync', 'sortd-categories-reorder'), $view_data);

	}

    public function getHtml($pid, $level, $project_id ){

        if($level>=20){
            return false;
        }
        

        if(!empty($this->all_categories)){
            foreach($this->all_categories as $catg){
                
                $category_id = $catg->term_id;
                
                $cat_option_value = Sortd_Helper::get_options_for_category($project_id,$category_id);
                
                if($cat_option_value == 1){
                    $value_checked='checked';
                } else{
                    $value_checked = '';
                }
                
                $cat_sync_sortd = Sortd_Helper::get_options_for_categoryid($project_id,$category_id);
               
                if($catg->parent == $pid){

                    $this->html  .= '<tr id="tr-'.$catg->term_id.'" data-parent="'.$catg->parent.'"  data-cat_id="'.$catg->term_id.'" data-sync_flag="'.$cat_option_value.'">';
                    for($i=0;$i< $level;$i++){
                        $this->html .= '<td></td><td></td><td></td>';
                    }
                    $cat_sync_sortd_parent = Sortd_Helper::get_options_for_category($project_id,$catg->parent);
                    if( $cat_sync_sortd_parent == 1 && $catg->parent !== 0){
                      $prop = "";

                    } else {
                        if($catg->parent == 0){
                            $prop="";
                            
                        } else {
                            $prop="disabled";
                            
                        }
                     
                    }

              

                    $this->html  .= '<td class="inputMsg catDynamic_'.wp_kses_data($catg->term_id).'" data-sortdindex="'.wp_kses_data($cat_sync_sortd).'" id="'.wp_kses_data($catg->term_id).'">'.wp_kses_data($catg->name). ' 
                                    </td>
                                    <td>
                                    <label class="switch-tog" >
                                    <input  data-parent="'.$catg->parent.'" type="checkbox" '.$prop.' name="checkbox" '.esc_attr($value_checked).' class="sortCatCheck sortcheckclass'.esc_attr($catg->term_id).'" id="'.esc_attr($catg->term_id).'" data-nonce="'.wp_kses_data(wp_create_nonce(`rw-sortd-cat-sync-`.$catg->term_id)).'">
                                    <span class="slider-tog round"></span>
                                    </label>
                                    </td>
                                   
                                    <td class="succmsg'.$catg->term_id.'" style="display:none;"><img style="display:none;" class="img'.esc_attr($catg->term_id).'" src="'.wp_kses_data(SORTD_CSS_URL).'/check.png"></td>
                                    
                                </tr>
                                ';

         
                   $this->getHtml($catg->cat_ID, ++$level,$project_id);
         
                    $level--;
                }
            }
            

            return true;

        } else {
            return false;
        }

      
        
    }
        
        /**
	 *  function for save rename category 
	 *
	 * @since    2.0.0
	 */
	public function save_renamed_category() {

            if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
                    $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
                    echo wp_kses_data($result); wp_die();
            }

            if(isset($_POST['id'])){
                $cat_id_new = sanitize_text_field($_POST['id']);
            }

            if(isset($_POST['name'])){
                $cat_name =sanitize_text_field($_POST['name']);
            }

            if(isset($_POST['alias'])){
                $cat_alias = sanitize_text_field($_POST['alias']);
            }

            $paramsrename = '{
                   "cat_id" : "'.$cat_id_new.'",
                   "name" : "'.$cat_name.'",
                   "alias" : "'.$cat_alias.'"            
             }';

            $category_rename_api_slug = "contentsettings/categoryrename";

            $response = Sortd_Helper::sortd_post_api_response($category_rename_api_slug,$paramsrename); 
         
            $project_id =Sortd_Helper::get_project_id(); 
            
            $categories_api_slug =  "contentsettings/listcategories";
    
            $response_cat = Sortd_Helper::sortd_get_api_response($categories_api_slug,'v2');

            $data['response'] = json_decode($response);
            $data['responseCat'] = json_decode($response_cat);

            echo (wp_json_encode($data));

            wp_die();

	}
        
        /**
	 *  function for save reorder categories 
	 *
	 * @since    2.0.0
	 */
	public function save_reordered_categories() {

            if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
                $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
                echo wp_kses_data($result); wp_die();
            }

            if(isset($_POST['category_order_old'])){
                $category_order_old = sanitize_text_field($_POST['category_order_old']);
            }

            if(isset($_POST['category_order'])){
                $category_order_new = sanitize_text_field($_POST['category_order']);
            }

            if(isset($_POST['cat_id'])){
                $cat_id = sanitize_text_field($_POST['cat_id']);
            }
            if(isset($_POST['after_cat_id'])){
                $after_cat_id = sanitize_text_field($_POST['after_cat_id']);
            }


	  //  if (strcasecmp($category_order_old, $category_order_new) != 0) { 
                $json_data = stripslashes(html_entity_decode($category_order_new));
                $data = json_decode($json_data,true);
                $new_categories_order = array();

                foreach ($data as $order => $category) {
	            $cat_data = array();
	            $cat_data['_id'] = $category['id'];
	            $cat_data['cat_type'] = 1;
	            $cat_data['order'] = $order+1;
	            $cat_data['parent_id'] = null;
	            $new_categories_order[] = $cat_data;

	            if (isset($category['children'])) {
	              foreach ($category['children'] as $sub_order => $sub_cat) {
	                $cat_data = array();
	                $cat_data['_id'] = $sub_cat['id'];
	                $cat_data['cat_type'] = 2;
	                $cat_data['order'] = $sub_order+1;
	                $cat_data['parent_id'] = $category['id'];
	                $new_categories_order[] = $cat_data;                  
	                }         
	            }         
                }

            $cat_data_param['cat_guid'] = $cat_id;
            $cat_data_param['after_cat_id'] = $after_cat_id;
	        $params = json_encode($cat_data_param);
	        $category_reorder_api_slug = "contentsettings/categoryreorder";
	        
	        $response =Sortd_Helper::sortd_post_api_response($category_reorder_api_slug, $params,'v2');

	        $decode = json_decode($response);

            $cat_data=$this->_get_sortd_categories();

                if($decode->status == 1){
                       update_option('sortd_sync_reorder_status',0);
                }

            echo json_encode($cat_data);
            //echo $decode;die;
          //  }

            wp_die();
	}
        
        
        /**
	 *  function for sync category
	 *
	 * @since    2.0.0
	 */
	public function sync_category() {
            
            if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
                $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
                echo wp_kses_data($result); wp_die();
            }
			

            try {

               
                if(isset($_POST['id'])){
                    $cat_id = sanitize_text_field($_POST['id']);
                }

                if(isset($_POST['flag'])){
                    $flag = sanitize_text_field($_POST['flag']);
                }
              
              

                if(isset($_POST['typeId'])){
                    $type_id = sanitize_text_field($_POST['typeId']);
                }

                if(isset($_POST['after_cat_id'])){
                    $after_cat_id = ($_POST['after_cat_id']);
                }

                $catinfo = get_category($cat_id);
                $cat_url = get_category_link($cat_id);
                $category_desc = strip_tags(trim(category_description($cat_id)));

                if(isset($_POST['parent_id'])){
                    $parent_id = ($_POST['parent_id']);
                }

                if(is_plugin_active('wordpress-seo/wp-seo.php')) {
                    $yoast_data = get_option( 'wpseo_taxonomy_meta');
                    if(isset($yoast_data) && !empty($yoast_data)) {
                        foreach($yoast_data['category'] as $cid => $data) {
                            if($cid == $cat_id) {
                                if($data['wpseo_title']) {
                                    $cat_title = $data['wpseo_title'];
                                }
                            }
                        }
                    }
                } else {
                    $cat_title = $catinfo->name;
                }
                
                $project_id = Sortd_Helper::get_project_id();
             
                if($flag == 'true'){
                    $params = '{
                               "cat_guid" : "'.$cat_id.'",
                               "name" : "'.$catinfo->name.'",
                               "alias" : "'.urldecode($catinfo->slug).'",
                               "parent_guid" : '.$parent_id.',
                               "after_cat_id": "'.$after_cat_id.'",
                               "cat_desc" : "'.$category_desc.'",
                               "cat_url": "'.$cat_url.'",
                               "cat_title": "'.$cat_title.'"
                    }';
                    // echo $params;die;
                  

                    $cat_sync_api_slug = "contentsettings/categorysync";
                    
                    $response = Sortd_Helper::sortd_post_api_response($cat_sync_api_slug,$params,'v2');

                    $response = json_decode($response);

                    if($response->status==1){
                        Sortd_Helper::create_options_for_category($project_id,$cat_id,1,$response->data->_id);
                        update_option('sortd_catsynconeclick_'.$project_id,1);
                        update_option('sortd_one_click_manual_sync'.$project_id,1);	
                    }
                    
                } else {
                    
                    $cat_sync_api_slug = "contentsettings/categoryremove";
                    $params = '{
                        "cat_guid" : "'.$cat_id.'"
                    }';

                
                    $response = Sortd_Helper::sortd_post_api_response($cat_sync_api_slug,$params,'v2');
                    $response = json_decode($response);
                  
                    if($response->status==1){
                  
                            Sortd_Helper::create_options_for_category($project_id,$cat_id,0,'');
			         

                        update_option('sortd_catsynconeclick_'.$project_id,0);	
                    }

                }

	   		
                $option = Sortd_Helper::get_options_for_category($project_id,$cat_id); 

                $result = array('option'=>$option,'response'=>$response,'flag'=>$flag);

                echo (wp_json_encode($result));

            } catch (Exception $e){

            }

            wp_die();
	}
        
        /**
	 *  function for delete category
	 *
	 * @since    2.0.0
     * 
	 */


	public function delete_category($tt_id) {

        $cats = $this->_get_sortd_categories();
        $childcat = array();
        //echo "<pre>"; print_r($cats);
        foreach($cats->data->categories as $sortd_cat){

           if(!empty($sortd_cat->parent_id)){

            //    foreach($sortd_cat->parent_id as $kcat  =>  $sortd_pid){
            //     echo "<pre>";print_r($sortd_pid);
                   if($sortd_cat->parent_id->cat_guid==$tt_id){
                       array_push($childcat,$sortd_cat->cat_guid);
                       
                   }
               //}
           }
           

           
        }

       // echo "<pre>";print_r($childcat);
        $cat_sync_api_slug = "contentsettings/categoryremove";

        if(!empty($childcat)){
           foreach($childcat as $sortd_childcat_value){
               $params = '{"cat_guid" : "'.$sortd_childcat_value.'"}';
   
               $response = Sortd_Helper::sortd_post_api_response($cat_sync_api_slug,$params,'v2');
               $responseChildUnsync = json_decode($response);
               $project_id = Sortd_Helper::get_project_id();

               //echo "<pre>";print_r($response);
               if($responseChildUnsync->status == 1){
                 Sortd_Helper::create_options_for_category($project_id,$sortd_childcat_value,0,'');
                 
                 
               }
               
   
            }
        }




        
        $params = '{
            "cat_guid" : "'.$tt_id.'"
         }';


         

         
         
     
         $response = Sortd_Helper::sortd_post_api_response($cat_sync_api_slug,$params,'v2');
         $responseparentUnsync = json_decode($response);
         $project_id = Sortd_Helper::get_project_id();

         if($responseparentUnsync->status == 1){

           Sortd_Helper::create_options_for_category($project_id,$tt_id,0,'');
           update_option('sortd_catsynconeclick_'.$tt_id,0);

         }
         


   }
       
        
        /**
	 *  function for reorder,rename via ajax
	 *
	 * @since    2.0.0
	 */
	public function reorder_rename_category_ajax() {

            if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
                    $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
                    echo wp_kses_data($result); wp_die();
            }

	        $project_id = get_option('sortd_projectid');
	    
            $api_slug = 'contentsettings/listcategories';
            $response = Sortd_Helper::sortd_get_api_response($api_slug,'v2');

            echo wp_kses_data($response);

            wp_die();

	}


    private function _get_sortd_categories(){
        $project_id = get_option('sortd_projectid');
	    
        $api_slug = 'contentsettings/listcategories';
        $response = Sortd_Helper::sortd_get_api_response($api_slug,'v2');
        $sorted_categories = json_decode($response);

        return $sorted_categories;
    }

    public function get_cat_child($id){

        $cat_id = $id;

        echo wp_kses_data($cat_id);
        $parent_cat_arg = array('hide_empty' => true, 'parent' => $cat_id );
        $children = get_terms('category',$parent_cat_arg);//category name
        // print_r($children);
        return $children;
        
    }



    public function sortd_get_categories(){
        if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
            $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
            echo wp_kses_data($result); wp_die();
        }

        $cats = $this->_get_sortd_categories();
        $array['categories'] = $cats;
      
        
        foreach($cats->data->categories as $k => $v){
            $get_term_children[$v->cat_guid]=  get_categories(
                array( 'parent' => $v->cat_guid )
            ); 
        }

        $array['children'] = $get_term_children;
     
        echo json_encode($array);

        wp_die();

    }


    public function get_cat_children(){
        if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
            $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
            echo wp_kses_data($result); wp_die();
        }

        $cat_id = "";
        if(isset($_POST['id'])){
            $cat_id = $_POST['id'];
        }
        $parent_cat_arg = array('hide_empty' => false, 'parent' => $cat_id );
        $children = get_terms('category',$parent_cat_arg);//category name
        echo json_encode($children);
        wp_die();

    }


    public function get_all_heirarchy_cat_children(){
        if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
            $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
            echo wp_kses_data($result); wp_die();
        }

        $cat_id = "";
        if(isset($_POST['id'])){
            $cat_id = $_POST['id'];
        }
        $get_all_children = get_term_children($cat_id,'category');
        echo json_encode($get_all_children);
        wp_die();
    }
        

    public function check_for_synced(){
        if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
            $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
            echo wp_kses_data($result); wp_die();
        }

        $cat_flag = false;

        $ids = "";
        if(isset($_POST['id'])){
            $ids = $_POST['id'];
        }
        $project_id = get_option('sortd_projectid');
        foreach($ids as $k => $v){
            $get_option = get_option('sortd_'.$project_id.'_category_sync_'.$v);

            if($get_option == 1){
                $cat_flag = true;
            }
        }
        echo json_encode($cat_flag);
        wp_die();
    }

    public static function update_category_url_redirection() {
        if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
            $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
            echo wp_kses_data($result); wp_die();
        }

        $article_url_redirection_flag = get_option('article_url_redirection_flag');
        $category_url_redirection_flag = get_option('category_url_redirection_flag');
        
        if(isset($_POST['article_toggle_value'])){
            $article_toggle_value = sanitize_text_field($_POST['article_toggle_value']);
        } else {
            $article_toggle_value = get_option('article_url_redirection_flag');
        }

        if(isset($_POST['category_toggle_value'])){
            $category_toggle_value = sanitize_text_field($_POST['category_toggle_value']);
        } else {
            $category_toggle_value = get_option('category_url_redirection_flag');
        }

        $redirect_api_slug = 'project/update-redirection-settings';
      
        $params = '{
            "enable_category_in_article" : '.$article_toggle_value.',
            "enable_category_alias_url" : '.$category_toggle_value.'          
        }';
        
        $redirect_response = Sortd_Helper::sortd_post_api_response($redirect_api_slug, $params);
        $response = json_decode($redirect_response);

        if($response->status == 1 && $category_url_redirection_flag == 0) {
            update_option('category_url_redirection_flag', 1);
        } elseif($response->status == 1 && $category_url_redirection_flag == 1) {
            update_option('category_url_redirection_flag', 0);
        }

        echo $redirect_response; wp_die();
    }   

    public static function update_article_url_redirection() {
        if(!check_ajax_referer('sortd-ajax-nonce-category', 'sortd_nonce')) {
            $result = '{"status":false,"error":{"message":"Sorry, your nonce did not verify","errorCode":403}}';
            echo wp_kses_data($result); wp_die();
        }

        $article_url_redirection_flag = get_option('article_url_redirection_flag');
        $category_url_redirection_flag = get_option('category_url_redirection_flag');
        
        if(isset($_POST['article_toggle_value'])){
            $article_toggle_value = sanitize_text_field($_POST['article_toggle_value']);
        } else {
            $article_toggle_value = get_option('article_url_redirection_flag');
        }

        if(isset($_POST['category_toggle_value'])){
            $category_toggle_value = sanitize_text_field($_POST['category_toggle_value']);
        } else {
            $category_toggle_value = get_option('category_url_redirection_flag');
        }

        $redirect_api_slug = 'project/update-redirection-settings';
      
        $params = '{
            "enable_category_in_article" : '.$article_toggle_value.',
            "enable_category_alias_url" : '.$category_toggle_value.'          
        }';
        
        $redirect_response = Sortd_Helper::sortd_post_api_response($redirect_api_slug, $params);
        $response = json_decode($redirect_response);
        if($response->status == 1 && $article_url_redirection_flag == 0) {
            update_option('article_url_redirection_flag', 1);
        } elseif($response->status == 1 && $article_url_redirection_flag == 1) {
            update_option('article_url_redirection_flag', 0);
        }

        echo $redirect_response; wp_die();
    }
       

}
